import { pgTable, uuid, timestamp, index, uniqueIndex } from 'drizzle-orm/pg-core';
import { persons } from './persons';
import { tags } from './tags';

/**
 * Person to Tag relation table schema
 */
export const personToTag = pgTable('person_to_tag', {
  id: uuid('id').primaryKey().defaultRandom(),
  personId: uuid('personId').notNull().references(() => persons.id, { onDelete: 'cascade' }),
  tagId: uuid('tagId').notNull().references(() => tags.id, { onDelete: 'cascade' }),
  createdAt: timestamp('createdAt', { withTimezone: true }).defaultNow().notNull()
}, (table) => {
  return {
    personIdIdx: index('ptt_personId_idx').on(table.personId),
    tagIdIdx: index('ptt_tagId_idx').on(table.tagId),
    personTagUniqueIdx: uniqueIndex('ptt_person_tag_unique_idx').on(table.personId, table.tagId)
  };
});

/**
 * PersonToTag type definitions
 */
export type PersonToTag = typeof personToTag.$inferSelect;
export type NewPersonToTag = typeof personToTag.$inferInsert;
